@@ -18,10 +18,23 @@ sub new {
 # evil assumption - no query strings on URL!
 sub versions {
     my ($self, $lastflag) = @_;
-	my $current_version = $self->vss_object->VersionNumber;
+    my $current_version = $self->vss_object->VersionNumber;
     map {
         VCS::Vss::Version->new("$self->{URL}/$_")
     } (1..$current_version);
 }
 
+sub url {
+   my ($self) = @_;
+   return $self->{URL};
+}
+
+sub tags {return ()}
+
+#sub path {
+#   my ($self) = @_;
+#   print "Getting path...\n";
+#   return $self->vss_object->Path;
+#}
+
 1;
